==> packageinstaller-pkglist-libre_0.1.6.tar.xz: packageinstaller-pkglist-libre/remmina.pm <==
<?xml version="1.0"?>
<app>

<category>
Remote Access
</category>

<name>
Remmina
</name>

<description>
   <am>Remote desktop client written in GTK+</am>
   <ar>Remote desktop client written in GTK+</ar>
   <be>Remote desktop client written in GTK+</be>
   <bg>Remote desktop client written in GTK+</bg>
   <bn>Remote desktop client written in GTK+</bn>
   <ca>Remote desktop client written in GTK+</ca>
   <cs>Remote desktop client written in GTK+</cs>
   <da>Remote desktop client written in GTK+</da>
   <de>Client für Fernzugriff auf den Desktop (verwendet die GTK Programmbibliothek)</de>
   <el>Πελάτης απομακρυσμένης επιφάνειας εργασίας γραμμένο σε GTK+</el>
   <en>Remote desktop client written in GTK+</en>
   <es_ES>Remote desktop client written in GTK+</es_ES>
   <es>Cliente de escritorio remoto escrito en GTK+</es>
   <et>Remote desktop client written in GTK+</et>
   <eu>Remote desktop client written in GTK+</eu>
   <fa>Remote desktop client written in GTK+</fa>
   <fil_PH>Remote desktop client written in GTK+</fil_PH>
   <fi>Remote desktop client written in GTK+</fi>
   <fr_BE>Remote desktop client written in GTK+</fr_BE>
   <fr>Client de bureau à distance écrit en GTK+</fr>
   <gl_ES>Remote desktop client written in GTK+</gl_ES>
   <he_IL>Remote desktop client written in GTK+</he_IL>
   <hi>Remote desktop client written in GTK+</hi>
   <hr>Remote desktop client written in GTK+</hr>
   <hu>Remote desktop client written in GTK+</hu>
   <id>Remote desktop client written in GTK+</id>
   <is>Remote desktop client written in GTK+</is>
   <it>Remote desktop client written in GTK+</it>
   <ja>GTK+で作られたリモートデスクトップ・クライアント</ja>
   <kk>Remote desktop client written in GTK+</kk>
   <ko>Remote desktop client written in GTK+</ko>
   <lt>Remote desktop client written in GTK+</lt>
   <mk>Remote desktop client written in GTK+</mk>
   <mr>Remote desktop client written in GTK+</mr>
   <nb_NO>Remote desktop client written in GTK+</nb_NO>
   <nb>Klient for eksternt skrivebord skrevet i GTK+</nb>
   <nl_BE>Remote desktop client written in GTK+</nl_BE>
   <nl>Remote desktop client written in GTK+</nl>
   <pl>Remote desktop client written in GTK+</pl>
   <pt_BR>Cliente de área de trabalho remoto escrito em GTK+</pt_BR>
   <pt>Remote desktop client written in GTK+</pt>
   <ro>Remote desktop client written in GTK+</ro>
   <ru>Remote desktop client written in GTK+</ru>
   <sk>Remote desktop client written in GTK+</sk>
   <sl>Remote desktop client written in GTK+</sl>
   <sq>Remote desktop client written in GTK+</sq>
   <sr>Remote desktop client written in GTK+</sr>
   <sv>Fjärrskrivbords-klient skriven i GTK+</sv>
   <th>Remote desktop client written in GTK+</th>
   <tr>Remote desktop client written in GTK+</tr>
   <uk>Remote desktop client written in GTK+</uk>
   <vi>Remote desktop client written in GTK+</vi>
   <zh_CN>Remote desktop client written in GTK+</zh_CN>
   <zh_HK>Remote desktop client written in GTK+</zh_HK>
   <zh_TW>Remote desktop client written in GTK+</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
remmina
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
remmina
</uninstall_package_names>
</app>

==> packageinstaller-pkglist-libre_0.1.7.tar.xz: packageinstaller-pkglist-libre/remmina.pm <==
<?xml version="1.0"?>
<app>

<category>
Remote Access
</category>

<name>
Remmina
</name>

<description>
   <am>Remote desktop client written in GTK+</am>
   <ar>Remote desktop client written in GTK+</ar>
   <be>Remote desktop client written in GTK+</be>
   <bg>Remote desktop client written in GTK+</bg>
   <bn>Remote desktop client written in GTK+</bn>
   <ca>Remote desktop client written in GTK+</ca>
   <cs>Remote desktop client written in GTK+</cs>
   <da>Remote desktop client written in GTK+</da>
   <de>Client für Fernzugriff auf den Desktop (verwendet die GTK Programmbibliothek)</de>
   <el>Πελάτης απομακρυσμένης επιφάνειας εργασίας γραμμένο σε GTK+</el>
   <en>Remote desktop client written in GTK+</en>
   <es_ES>Remote desktop client written in GTK+</es_ES>
   <es>Cliente de escritorio remoto escrito en GTK+</es>
   <et>Remote desktop client written in GTK+</et>
   <eu>Remote desktop client written in GTK+</eu>
   <fa>Remote desktop client written in GTK+</fa>
   <fil_PH>Remote desktop client written in GTK+</fil_PH>
   <fi>Remote desktop client written in GTK+</fi>
   <fr_BE>Client de bureau à distance écrit en GTK+</fr_BE>
   <fr>Client de bureau à distance écrit en GTK+</fr>
   <gl_ES>Remote desktop client written in GTK+</gl_ES>
   <he_IL>Remote desktop client written in GTK+</he_IL>
   <hi>Remote desktop client written in GTK+</hi>
   <hr>Remote desktop client written in GTK+</hr>
   <hu>Remote desktop client written in GTK+</hu>
   <id>Remote desktop client written in GTK+</id>
   <is>Remote desktop client written in GTK+</is>
   <it>Remote desktop client written in GTK+</it>
   <ja>GTK+で作られたリモートデスクトップ・クライアント</ja>
   <kk>Remote desktop client written in GTK+</kk>
   <ko>Remote desktop client written in GTK+</ko>
   <lt>Remote desktop client written in GTK+</lt>
   <mk>Remote desktop client written in GTK+</mk>
   <mr>Remote desktop client written in GTK+</mr>
   <nb_NO>Remote desktop client written in GTK+</nb_NO>
   <nb>Klient for eksternt skrivebord skrevet i GTK+</nb>
   <nl_BE>Remote desktop client written in GTK+</nl_BE>
   <nl>Remote desktop client written in GTK+</nl>
   <pl>Remote desktop client written in GTK+</pl>
   <pt_BR>Cliente de área de trabalho remoto escrito em GTK+</pt_BR>
   <pt>Remote desktop client written in GTK+</pt>
   <ro>Remote desktop client written in GTK+</ro>
   <ru>Remote desktop client written in GTK+</ru>
   <sk>Remote desktop client written in GTK+</sk>
   <sl>Remote desktop client written in GTK+</sl>
   <sq>Remote desktop client written in GTK+</sq>
   <sr>Remote desktop client written in GTK+</sr>
   <sv>Fjärrskrivbords-klient skriven i GTK+</sv>
   <th>Remote desktop client written in GTK+</th>
   <tr>Remote desktop client written in GTK+</tr>
   <uk>Remote desktop client written in GTK+</uk>
   <vi>Remote desktop client written in GTK+</vi>
   <zh_CN>Remote desktop client written in GTK+</zh_CN>
   <zh_HK>Remote desktop client written in GTK+</zh_HK>
   <zh_TW>Remote desktop client written in GTK+</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
remmina
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
remmina
</uninstall_package_names>
</app>
